==> pyfi_helper-0.1.14.tar.gz: pyfi_helper-0.1.14/pyfi/mapper.py <==
from pyfi.data_agent import *
from pyfi.common import Map

# 当前使用的label
label = Map({
    "经济增长": {
        "生产": {
            "ip_yoy": "M0000545",
            "ip_cyoy": "M0000011",

        },
        "消费": {
            "社会消费品零售总额增速": None,
            "城镇居民人均可支配收入增速": None
        },
        "投资": {

        },
    },
    "通货膨胀": {
        "通胀指标": {
            "cpi": "M0000612",
            "cpif": "M0000616",
            "cpinf": "M0000613",
            "cpicore": "M0085932",
            "ppi": "M0001227",
            "cgpi": "M0001375",  # "企业商品交易价格指数"
        }
    },
    "外部环境": {
        "汇率条件": {
            "USDNH_即期汇率": "M0290205",
        }

    },
    "gz1y": "M1001646",
    "gz2y": "S0059745",
    "gz3y": "M1001648",
    "gz4y": "M0057946",
    "gz5y": "M1001650",
    "gz6y": "M0057947",
    "gz7y": "S0059748",
    "gz8y": "M1000165",
    "gz9y": "M1004678",
    "gz10y": "S0059749",
    "gz20y": "S0059751",
    "gz30y": "S0059752",
    "gk10y": "M1004271",
    "gk7y": "M1004269",
    "gk5y": "M1004267",
    "gk3y": "M1004265",
    "gk1y": "M1004687",
    "gc007": "204007.SH",
    "gc001": "204001.SH",
    "gc014": "204014.SH",
    "gc028": "204028.SH",
    "gc091": "204091.SH",
    "r007": "M1001795",
    "1yfr007": "M0048486",
    "5yfr007": "M0048490",
    "M2": "M0001385",
    "水泥价格指数": "S5914515",
    "CRB": "S0031505",
    "gz10yind": "CBA04501.CS",
    "玻璃综合指数": "S5907372",
    "螺纹钢": "S5707798",
    "fai_cyoy": "M0000273",
    # 大类资产模块
    "winda": "",
    "rb": "",
    "copper": "",
    "brent": "S0260035",  # 布伦特原油活跃期货合约结算价
})

mapper = Map({
    "ip_yoy": "M0000545",
    "ip_cyoy": "M0000011",
    "cpi": "M0000612",
    "cpif": "M0000616",
    "cpinf": "M0000613",
    "cpicore": "M0085932",
    "ppi": "M0001227",
    "cgpi": "M0001375",  # "企业商品交易价格指数"
    "USDNH:即期汇率": "M0290205",
    "gz1y": "M1001646",
    "gz2y": "S0059745",
    "gz3y": "M1001648",
    "gz4y": "M0057946",
    "gz5y": "M1001650",
    "gz6y": "M0057947",
    "gz7y": "S0059748",
    "gz8y": "M1000165",
    "gz9y": "M1004678",
    "gz10y": "S0059749",
    "gz20y": "S0059751",
    "gz30y": "S0059752",
    "gk10y": "M1004271",
    "gk7y": "M1004269",
    "gk5y": "M1004267",
    "gk3y": "M1004265",
    "gk1y": "M1004687",
    "gc007": "204007.SH",
    "gc001": "204001.SH",
    "gc014": "204014.SH",
    "gc028": "204028.SH",
    "gc091": "204091.SH",
    "r007": "M1001795",
    "1yfr007": "M0048486",
    "5yfr007": "M0048490",
    "M2": "M0001385",
    "水泥价格指数": "S5914515",
    "CRB": "S0031505",
    "gz10yind": "CBA04501.CS",
    "玻璃综合指数": "S5907372",
    "螺纹钢": "S5707798",
    "fai_cyoy": "M0000273",
    # 大类资产模块
    "winda": "",
    "rb": "",
    "copper": "",
    "brent": "S0260035",  # 布伦特原油活跃期货合约结算价
})

da_mapper = {
    "水泥指数": shuini,
    "环渤海动力煤指数": hbhdlm
}

==> pyfi_helper-0.1.16.tar.gz: pyfi_helper-0.1.16/pyfi/mapper.py <==
from pyfi.data_agent import *
from pyfi.common import Map

# 当前使用的label
label = Map({
    "经济增长": {
        "生产": {
            "ip_yoy": "M0000545",
            "ip_cyoy": "M0000011",

        },
        "消费": {
            "社会消费品零售总额增速": None,
            "城镇居民人均可支配收入增速": None
        },
        "投资": {

        },
    },
    "通货膨胀": {
        "通胀指标": {
            "cpi": "M0000612",
            "cpif": "M0000616",
            "cpinf": "M0000613",
            "cpicore": "M0085932",
            "ppi": "M0001227",
            "cgpi": "M0001375",  # "企业商品交易价格指数"
        }
    },
    "外部环境": {
        "汇率条件": {
            "USDNH_即期汇率": "M0290205",
        }

    },
    "gz1y": "M1001646",
    "gz2y": "S0059745",
    "gz3y": "M1001648",
    "gz4y": "M0057946",
    "gz5y": "M1001650",
    "gz6y": "M0057947",
    "gz7y": "S0059748",
    "gz8y": "M1000165",
    "gz9y": "M1004678",
    "gz10y": "S0059749",
    "gz20y": "S0059751",
    "gz30y": "S0059752",
    "gk10y": "M1004271",
    "gk7y": "M1004269",
    "gk5y": "M1004267",
    "gk3y": "M1004265",
    "gk1y": "M1004687",
    "gc007": "204007.SH",
    "gc001": "204001.SH",
    "gc014": "204014.SH",
    "gc028": "204028.SH",
    "gc091": "204091.SH",
    "r007": "M1001795",
    "1yfr007": "M0048486",
    "5yfr007": "M0048490",
    "M2": "M0001385",
    "水泥价格指数": "S5914515",
    "CRB": "S0031505",
    "gz10yind": "CBA04501.CS",
    "玻璃综合指数": "S5907372",
    "螺纹钢": "S5707798",
    "fai_cyoy": "M0000273",
    "brent": "S0260035",  # 布伦特原油活跃期货合约结算价
})

mapper = Map({
    "ip_yoy": "M0000545",
    "ip_cyoy": "M0000011",
    "cpi": "M0000612",
    "cpif": "M0000616",
    "cpinf": "M0000613",
    "cpicore": "M0085932",
    "ppi": "M0001227",
    "cgpi": "M0001375",  # "企业商品交易价格指数"
    "USDNH即期汇率": "M0290205",
    "gz1y": "M1001646",
    "gz2y": "S0059745",
    "gz3y": "M1001648",
    "gz4y": "M0057946",
    "gz5y": "M1001650",
    "gz6y": "M0057947",
    "gz7y": "S0059748",
    "gz8y": "M1000165",
    "gz9y": "M1004678",
    "gz10y": "S0059749",
    "gz20y": "S0059751",
    "gz30y": "S0059752",
    "gk10y": "M1004271",
    "gk7y": "M1004269",
    "gk5y": "M1004267",
    "gk3y": "M1004265",
    "gk1y": "M1004687",
    "gc007": "204007.SH",
    "gc001": "204001.SH",
    "gc014": "204014.SH",
    "gc028": "204028.SH",
    "gc091": "204091.SH",
    "r007": "M1001795",
    "fr0071y": "M0048486",
    "fr0075y": "M0048490",
    "M2": "M0001385",
    "水泥价格指数": "S5914515",
    "CRB": "S0031505",
    "gz10yind": "CBA04501.CS",
    "玻璃综合指数": "S5907372",
    "螺纹钢": "S5707798",
    "fai_cyoy": "M0000273",
    # 大类资产模块
    "winda": "",
    "rb": "",
    "copper": "",
    "brent": "S0260035",  # 布伦特原油活跃期货合约结算价
})

da_mapper = {
    "水泥指数": shuini,
    "环渤海动力煤指数": hbhdlm
}
